@@ -5,9 +5,10 @@ use warnings;
 use Net::DNS;
 use base qw(Net::DNS::Resolver DynaLoader);
 
+our $VERSION;
+
 BEGIN {
-	our $VERSION;
-	$VERSION = '1.19_01';
+	$VERSION = '1.19_02';
 	eval { __PACKAGE__->bootstrap($VERSION) };
 }
 
@@ -96,9 +97,19 @@ sub new {
 	nameservers => [],		# override /etc/resolv.conf
 	);
 
+    my @nameservers = $stub_resolver->nameservers;
+
 By default, DNS queries are sent to the IP addresses listed in
 /etc/resolv.conf or similar platform-specific sources.
 
+=cut
+
+sub nameservers {
+	my $self = shift;
+	local $self->{debug};		## "no nameservers" ok in this context
+	return $self->SUPER::nameservers(@_);
+}
+
 
 =head2 search, query, send, bgsend, bgbusy, bgread
 
@@ -356,9 +367,10 @@ sub debug_level {
 
     $resolver->async_thread(1);
 
+Set the context behaviour for asynchronous actions.
 Enable a call to resolve_async() to create a thread to handle work in
-the background. If false (by default), a process is forked to perform
-the work.
+the background.
+If false (by default), a process is forked to perform the work.
 
 =cut
 
@@ -368,17 +380,21 @@ sub async_thread {
 }
 
 
-########################################
+=head2 print, string
 
-sub nameservers {
-	my $self = shift;
-	local $self->{debug};		## "no nameservers" ok in this context
-	return $self->SUPER::nameservers(@_);
+    $resolver->print;
+    print $resolver->string;
+
+Prints the resolver state on the standard output.
+
+=cut
+
+sub print {
+	return print shift->string;
 }
 
 sub string {
 	my $self = shift;
-
 	$self = $self->_defaults unless ref($self);
 
 	my @nslist   = $self->nameservers();
@@ -394,10 +410,8 @@ sub string {
 END
 }
 
-sub print {
-	return print shift->string;
-}
 
+########################################
 
 sub _decode_result {
 	my ( $self, $result, $query_id ) = @_;
